
#include <stdio.h>

#include <xparameters.h>

// ***************************************************************************
#include "ui/ui.h"

// application menu
const ui_menu_t menu[] = {
  {'w', "I2C_PS Write register"               },
  {'W', "I2C_PS Write register and readback"  },
  {'r', "I2C_PS Read register"                },

  {'m', "Print this menu"               },
  {'x', "Quit"                          },
  {  0, NULL                            }
};


// ***************************************************************************
#include "i2c/i2c_ps.h"
i2c_ps_t i2c_ps;

// ***************************************************************************
// ***************************************************************************

int main()
{

    int status = 0;
    u8 key;
    u8 menu_print_en = 1;

    u8 reg;
    u8 val;

    printf("\n\n*****************************************************************************\n");
    printf(    "*  Signal Processing Dept., UTIA AV CR, v.v.i.                              *\n");
    printf(    "*  I2C_PS - TE0808 PMOD1 Example                                            *\n");
    printf(    "*****************************************************************************\n\n");


    printf("Initialize I2C_PS0 ...");
    i2c_ps.dev_id   = XPAR_PSU_I2C_0_DEVICE_ID;
    i2c_ps.sclk_hz  = I2C_PS_SCLK_RATE_400_KHZ;
    status = i2c_ps_init( &i2c_ps );
    if ( status != XST_SUCCESS ) {
        printf("FAILED (%d)\n", status);
        return XST_FAILURE;
    }
    printf("OK\n");


    printf("TCA9548 Select Port 0 - PMOD ... ");
    status = ic2_ps_9548_sel( &i2c_ps, I2C_PS_9548_SEL_PMOD );
    if ( status != XST_SUCCESS ) {
        printf("FAILED (%d)\n", status);
        return XST_FAILURE;
    }
    printf("OK\n");



    while (1) {

        /*
         * print menu
         */
        ui_print_menu("Menu", menu, &menu_print_en );

        /*
         * GUI - terminal
         */
        key = ui_getch_nb();
        if (key != 0xff) {

            switch(key) {

                case 'w':
//                     printf("Write slave 0x17, reg 0x01, data 0x55 ... ");
//                     status = i2c_ps_write_reg( &i2c_ps, 0x17, 0x01, 0x55 );
//                     if ( status != XST_SUCCESS ) {
//                         printf("FAILED (%d)\n", status);
//                     } else {
//                         printf("OK\n");
//                     }
//                     break;
                    printf("Write slave 0x17, register #0xXX:");
                    fflush(stdout);
                    reg = ui_get_address(8);
                    printf("\nValue #0xXX: ");
                    fflush(stdout);
                    val = ui_get_address(8);
                    printf("\n");
                    status = i2c_ps_write_reg( &i2c_ps, 0x17, reg, val );
                    if ( status != XST_SUCCESS ) {
                        printf("Write error (%d)\n", status);
                    }
                    break;

                case 'W':
                    printf("Write slave 0x17, register #0xXX:");
                    fflush(stdout);
                    reg = ui_get_address(8);
                    printf("\nValue #0xXX: ");
                    fflush(stdout);
                    val = ui_get_address(8);
                    status = i2c_ps_write_reg( &i2c_ps, 0x17, reg, val );
                    if ( status != XST_SUCCESS ) {
                        printf("Write error (%d)\n", status);
                    }
                    status = i2c_ps_read_reg( &i2c_ps, 0x17, reg, &val );
                    if ( status != XST_SUCCESS ) {
                        printf("Read error (%d)\n", status);
                    } else {
                        printf("\nReadback: reg 0x%02X = 0x%02X, 0b%s\n", reg, val, ui_conv_to_bin(val, 8));
                    }
                    break;

                case 'r':
//                     printf("Read slave 0x17, reg 0x00, ... ");
//                     status = i2c_ps_read_reg( &i2c_ps, 0x17, 0x00, &val );
//                     if ( status != XST_SUCCESS ) {
//                         printf("FAILED (%d)\n", status);
//                     } else {
//                         printf("OK, val = 0x%02X\n",val);
//                     }
//                     break;
                    printf("Read slave 0x17, register #0xXX:");
                    fflush(stdout);
                    reg = ui_get_address(8);
                    status = i2c_ps_read_reg( &i2c_ps, 0x17, reg, &val );
                    if ( status != XST_SUCCESS ) {
                        printf("Read error (%d)\n", status);
                    } else {
                        printf("\nreg 0x%02X = 0x%02X, 0b%s\n", reg, val, ui_conv_to_bin(val, 8));
                    }
                    break;


                case 'm':
                    menu_print_en = 1;
                    break;

                case 'x':
                    printf("Exiting ... \n");


//                     if (status != XST_SUCCESS) {
//                         printf("FAILED\n");
//                     } else {
//                         printf("OK\n");
//                     }

                    break;
            }
        }

    }


    return XST_SUCCESS;
}
